@@ -236,6 +236,10 @@ MOS_STATUS MosUtilities::MosGenerateUserFeatureKeyXML(MOS_CONTEXT_HANDLE mosCtx)
     {
         UserFeatureFilter.pcGroup = FilterGroups[uiIndex];
         eStatus = MosWriteOneUserFeatureGroupToXML(UserFeatureFilter);
+        if (eStatus!= MOS_STATUS_SUCCESS)
+        {
+            MOS_OS_ASSERTMESSAGE("Failed to Write One User FeatureGroup To XML");
+        }
     }
 
     // User Feature Key Header End
@@ -486,8 +490,13 @@ MOS_STATUS MosUtilities::MosAssignUserFeatureValueData(
             pDstData->MultiStringData.uCount          = 0;
             return MOS_STATUS_NULL_POINTER;
         }
+        MosAtomicIncrement(m_mosMemAllocFakeCounter);
         if ((pData != nullptr) && (strlen(pData) != 0))
         {
+            if (!pDstData->MultiStringData.pMultStringData)
+            {
+                MosAtomicIncrement(m_mosMemAllocFakeCounter);
+            }
             MOS_SafeFreeMemory(pDstData->MultiStringData.pMultStringData);
             pDstData->MultiStringData.pMultStringData = (char *)MOS_AllocAndZeroMemory(strlen(pData) + 1);
             if (pDstData->MultiStringData.pMultStringData == nullptr)
